**mathmodel**
=========

Hey, this is a seed generator to generate pypi seed  for you to quick start on sharing lib development \

- it provides 'cli' to customize the seed before generation

- a seed project that available to upload to pypi.org

- support the standard python project generation or CLI python lib generation( run with '--cli' option)

您好，这是一个pypi的种子项目，它能帮你快速生成python库模板，生成的项目稍微修改，就能上传到pypi分享自己的项目了 \

用途：

- 提供了cli（命令行工具帮你生成符合pypi上传要求的库）

- 本示例库有社区维护，还有大量专业的Python大佬一起合作。

- 支持生成普通标准Python模块或者cli库模版项目（加上--cli选项）



[ContactProjectTeam](https://github.com/py4ever/pypi_seed)

[联系作者](https://blog.csdn.net/geeklevin)

QQ交流：https://jq.qq.com/?_wv=1027&k=lYdDWNQc




Installation / 安装
--------------------------

::

    pip install pypi_seed



Usage / 使用
--------------------------

We can call the cli 'pypiseed' or 'pyseed' to generate 'demo_project' on dir '/tmp'：

调用下面任意一个命令行即可，作用是生成demo_project 到/tmp目录

::

    pypiseed --project=demo_project --author=testuser --dir=/tmp


Yet another option / 另一种方式：

::

    ppc --project=demo_project --author=testuser --dir=/tmp